==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/DeleteProgramRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteProgramRequest(
    channelName: __string,
    programName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest = {
    import DeleteProgramRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .programName(__string.unwrap(programName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteProgramRequest.wrap(buildAwsValue())
}
object DeleteProgramRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteProgramRequest =
      zio.aws.mediatailor.model.DeleteProgramRequest(channelName, programName)
    def channelName: __string
    def programName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ) extends zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
    override val programName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.programName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ): zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.295.4-sources.jar: zio/aws/mediatailor/model/DeleteProgramRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteProgramRequest(
    channelName: __string,
    programName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest = {
    import DeleteProgramRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .programName(programName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteProgramRequest.wrap(buildAwsValue())
}
object DeleteProgramRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteProgramRequest =
      zio.aws.mediatailor.model.DeleteProgramRequest(channelName, programName)
    def channelName: __string
    def programName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ) extends zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
    override val programName: __string = impl.programName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteProgramRequest
  ): zio.aws.mediatailor.model.DeleteProgramRequest.ReadOnly = new Wrapper(impl)
}
